BootstrapEndpoint class
Constructors
-
BootstrapEndpoint({int id = 0, required String network, required String endpointType, required String endpoint, required int lastTested, required int successRate, required int averageLatency, required bool isWorking, required int lastUpdated, required String source})
-
-
BootstrapEndpoint.create({required String network, required String endpointType, required String endpoint, String source = 'local'})
-
Properties
-
averageLatency
↔ int
-
Average latency in milliseconds
getter/setter pair
-
endpoint
↔ String
-
Endpoint URL
getter/setter pair
-
endpointType
↔ String
-
Endpoint type (rpc, squid)
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ int
-
getter/setter pair
-
isWorking
↔ bool
-
Is this endpoint currently working
getter/setter pair
-
lastTested
↔ int
-
Last tested timestamp (milliseconds since epoch)
getter/setter pair
-
lastUpdated
↔ int
-
Last update timestamp from remote config
getter/setter pair
-
network
↔ String
-
Network name (gtest, g1, etc.)
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
↔ String
-
Source of this endpoint (remote, local, discovery)
getter/setter pair
-
successRate
↔ int
-
Success rate (0-100)
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited