CertificationData class

Constructors

CertificationData({required int receivedCount, required int sentCount, int? nextIssuableOn})
CertificationData.empty()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
nextIssuableOn int?
final
receivedCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentCount int
final

Methods

equals(CertificationData? other) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited