CertificationFilters class

Represents filter criteria for certification queries

Constructors

CertificationFilters({String? issuerNameSearch, String? receiverNameSearch, String? issuerAccountId, String? receiverAccountId, DateTime? startDate, DateTime? endDate, bool? isActive = true, bool exactMatchIssuer = false, bool exactMatchReceiver = false})
const

Properties

endDate DateTime?
final
exactMatchIssuer bool
final
exactMatchReceiver bool
final
hasActiveFilters bool
Check if any filters are active
no setter
hashCode int
The hash code for this object.
no setterinherited
isActive bool?
final
issuerAccountId String?
final
issuerNameSearch String?
final
receiverAccountId String?
final
receiverNameSearch String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
final

Methods

copyWith({String? issuerNameSearch, String? receiverNameSearch, String? issuerAccountId, String? receiverAccountId, DateTime? startDate, DateTime? endDate, bool? isActive, bool? exactMatchIssuer, bool? exactMatchReceiver}) CertificationFilters
Copy with method for immutable updates
copyWithNullableActive({String? issuerNameSearch, String? receiverNameSearch, String? issuerAccountId, String? receiverAccountId, DateTime? startDate, DateTime? endDate, bool? isActive, bool clearIsActive = false, bool? exactMatchIssuer, bool? exactMatchReceiver}) CertificationFilters
Copy with method that allows setting isActive to null (to show all)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited