CertificationType enum
Type of certification operation
- Inheritance
- Available extensions
Values
- invitation → const CertificationType
-
Invitation to create a new identity
- renewal → const CertificationType
-
Renewal of an existing certification
- certification → const CertificationType
-
Standard certification
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encodeTo(
Output output) → void -
Available on T, provided by the EnumExtensions extension
Encodes value of Enum to the HexOutput / ByteOutput -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CertificationType> - A constant List of the values in this enum, in order of their declaration.