CopyWith$Input$CertFilter<TRes> class
abstract
Constructors
- CopyWith$Input$CertFilter(Input$CertFilter instance, TRes then(Input$CertFilter))
-
factory
- CopyWith$Input$CertFilter.stub(TRes res)
-
factory
Properties
-
certHistory
→ CopyWith$Input$CertToManyCertEventFilter<
TRes> -
no setter
-
createdIn
→ CopyWith$Input$EventFilter<
TRes> -
no setter
-
createdInId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
createdOn
→ CopyWith$Input$IntFilter<
TRes> -
no setter
-
expireOn
→ CopyWith$Input$IntFilter<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
isActive
→ CopyWith$Input$BooleanFilter<
TRes> -
no setter
-
issuer
→ CopyWith$Input$IdentityFilter<
TRes> -
no setter
-
issuerId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
not
→ CopyWith$Input$CertFilter<
TRes> -
no setter
-
receiver
→ CopyWith$Input$IdentityFilter<
TRes> -
no setter
-
receiverId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updatedIn
→ CopyWith$Input$EventFilter<
TRes> -
no setter
-
updatedInId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
updatedOn
→ CopyWith$Input$IntFilter<
TRes> -
no setter
Methods
-
and(
Iterable< Input$CertFilter> ? _fn(Iterable<CopyWith$Input$CertFilter< ?)) → TResInput$CertFilter> > -
call(
{Input$StringFilter? id, Input$BooleanFilter? isActive, Input$IntFilter? createdOn, Input$IntFilter? updatedOn, Input$IntFilter? expireOn, Input$StringFilter? issuerId, Input$StringFilter? receiverId, Input$StringFilter? createdInId, Input$StringFilter? updatedInId, Input$CertToManyCertEventFilter? certHistory, bool? certHistoryExist, Input$IdentityFilter? issuer, bool? issuerExists, Input$IdentityFilter? receiver, bool? receiverExists, Input$EventFilter? createdIn, bool? createdInExists, Input$EventFilter? updatedIn, bool? updatedInExists, List< Input$CertFilter> ? and, List<Input$CertFilter> ? or, Input$CertFilter? not}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
or(
Iterable< Input$CertFilter> ? _fn(Iterable<CopyWith$Input$CertFilter< ?)) → TResInput$CertFilter> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited