CopyWith$Input$ChangeOwnerKeyFilter<TRes> class
abstract
Constructors
- CopyWith$Input$ChangeOwnerKeyFilter(Input$ChangeOwnerKeyFilter instance, TRes then(Input$ChangeOwnerKeyFilter))
-
factory
- CopyWith$Input$ChangeOwnerKeyFilter.stub(TRes res)
-
factory
Properties
-
blockNumber
→ CopyWith$Input$IntFilter<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
identity
→ CopyWith$Input$IdentityFilter<
TRes> -
no setter
-
identityId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
next
→ CopyWith$Input$AccountFilter<
TRes> -
no setter
-
nextId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
not
→ CopyWith$Input$ChangeOwnerKeyFilter<
TRes> -
no setter
-
previous
→ CopyWith$Input$AccountFilter<
TRes> -
no setter
-
previousId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
and(
Iterable< Input$ChangeOwnerKeyFilter> ? _fn(Iterable<CopyWith$Input$ChangeOwnerKeyFilter< ?)) → TResInput$ChangeOwnerKeyFilter> > -
call(
{Input$StringFilter? id, Input$IntFilter? blockNumber, Input$StringFilter? identityId, Input$StringFilter? previousId, Input$StringFilter? nextId, Input$IdentityFilter? identity, bool? identityExists, Input$AccountFilter? previous, bool? previousExists, Input$AccountFilter? next, bool? nextExists, List< Input$ChangeOwnerKeyFilter> ? and, List<Input$ChangeOwnerKeyFilter> ? or, Input$ChangeOwnerKeyFilter? not}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
or(
Iterable< Input$ChangeOwnerKeyFilter> ? _fn(Iterable<CopyWith$Input$ChangeOwnerKeyFilter< ?)) → TResInput$ChangeOwnerKeyFilter> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited