CopyWith$Input$IdentityFilter<TRes> class
abstract
Constructors
- CopyWith$Input$IdentityFilter(Input$IdentityFilter instance, TRes then(Input$IdentityFilter))
-
factory
- CopyWith$Input$IdentityFilter.stub(TRes res)
-
factory
Properties
-
account
→ CopyWith$Input$AccountFilter<
TRes> -
no setter
-
accountId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
accountRemoved
→ CopyWith$Input$AccountFilter<
TRes> -
no setter
-
accountRemovedId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
accountsByLinkedIdentityId
→ CopyWith$Input$IdentityToManyAccountFilter<
TRes> -
no setter
-
certIssued
→ CopyWith$Input$IdentityToManyCertFilter<
TRes> -
no setter
-
certReceived
→ CopyWith$Input$IdentityToManyCertFilter<
TRes> -
no setter
-
createdIn
→ CopyWith$Input$EventFilter<
TRes> -
no setter
-
createdInId
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
createdOn
→ CopyWith$Input$IntFilter<
TRes> -
no setter
-
expireOn
→ CopyWith$Input$IntFilter<
TRes> -
no setter
-
firstEligibleUd
→ CopyWith$Input$IntFilter<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
index
→ CopyWith$Input$IntFilter<
TRes> -
no setter
-
isMember
→ CopyWith$Input$BooleanFilter<
TRes> -
no setter
-
lastChangeOn
→ CopyWith$Input$IntFilter<
TRes> -
no setter
-
membershipHistory
→ CopyWith$Input$IdentityToManyMembershipEventFilter<
TRes> -
no setter
-
name
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
not
→ CopyWith$Input$IdentityFilter<
TRes> -
no setter
-
ownerKeyChange
→ CopyWith$Input$IdentityToManyChangeOwnerKeyFilter<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
smith
→ CopyWith$Input$SmithFilter<
TRes> -
no setter
-
status
→ CopyWith$Input$StringFilter<
TRes> -
no setter
-
udHistoryRecords
→ CopyWith$Input$IdentityToManyUdHistoryFilter<
TRes> -
no setter
Methods
-
and(
Iterable< Input$IdentityFilter> ? _fn(Iterable<CopyWith$Input$IdentityFilter< ?)) → TResInput$IdentityFilter> > -
call(
{Input$StringFilter? id, Input$IntFilter? index, Input$StringFilter? name, Input$StringFilter? status, Input$IntFilter? createdOn, Input$IntFilter? lastChangeOn, Input$BooleanFilter? isMember, Input$IntFilter? expireOn, Input$IntFilter? firstEligibleUd, Input$StringFilter? accountId, Input$StringFilter? accountRemovedId, Input$StringFilter? createdInId, Input$IdentityToManyCertFilter? certIssued, bool? certIssuedExist, Input$IdentityToManyCertFilter? certReceived, bool? certReceivedExist, Input$IdentityToManyMembershipEventFilter? membershipHistory, bool? membershipHistoryExist, Input$IdentityToManyChangeOwnerKeyFilter? ownerKeyChange, bool? ownerKeyChangeExist, Input$SmithFilter? smith, bool? smithExists, Input$IdentityToManyUdHistoryFilter? udHistoryRecords, bool? udHistoryRecordsExist, Input$IdentityToManyAccountFilter? accountsByLinkedIdentityId, bool? accountsByLinkedIdentityIdExist, Input$AccountFilter? account, bool? accountExists, Input$AccountFilter? accountRemoved, bool? accountRemovedExists, Input$EventFilter? createdIn, bool? createdInExists, List< Input$IdentityFilter> ? and, List<Input$IdentityFilter> ? or, Input$IdentityFilter? not}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
or(
Iterable< Input$IdentityFilter> ? _fn(Iterable<CopyWith$Input$IdentityFilter< ?)) → TResInput$IdentityFilter> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited