CopyWith$Input$UdHistoryCondition<TRes> class
abstract
Constructors
- CopyWith$Input$UdHistoryCondition(Input$UdHistoryCondition instance, TRes then(Input$UdHistoryCondition))
-
factory
- CopyWith$Input$UdHistoryCondition.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? id, String? amount, int? blockNumber, String? timestamp, String? identityId}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited