CopyWith$Query$GetAccountStatus<TRes> class abstract

Properties

accounts CopyWith$Query$GetAccountStatus$accounts<TRes>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({Query$GetAccountStatus$accounts? accounts, String? $__typename}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited