CopyWith$Query$GetNetworkCertifications$certs$edges$node$updatedIn<TRes> class
abstract
Constructors
- CopyWith$Query$GetNetworkCertifications$certs$edges$node$updatedIn(Query$GetNetworkCertifications$certs$edges$node$updatedIn instance, TRes then(Query$GetNetworkCertifications$certs$edges$node$updatedIn))
-
factory
- CopyWith$Query$GetNetworkCertifications$certs$edges$node$updatedIn.stub(TRes res)
-
factory
Properties
-
block
→ CopyWith$Query$GetNetworkCertifications$certs$edges$node$updatedIn$block<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{Query$GetNetworkCertifications$certs$edges$node$updatedIn$block? block, String? $__typename}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited