CopyWith$Query$GetNetworkCertificationsFiltered$certs<TRes> class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
pageInfo CopyWith$Query$GetNetworkCertificationsFiltered$certs$pageInfo<TRes>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({List<Query$GetNetworkCertificationsFiltered$certs$edges>? edges, Query$GetNetworkCertificationsFiltered$certs$pageInfo? pageInfo, String? $__typename}) → TRes
edges(Iterable<Query$GetNetworkCertificationsFiltered$certs$edges> _fn(Iterable<CopyWith$Query$GetNetworkCertificationsFiltered$certs$edges<Query$GetNetworkCertificationsFiltered$certs$edges>>)) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited