CopyWith$Subscription$SubscribeNetworkIdentities$identities<TRes> class
abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{List< Subscription$SubscribeNetworkIdentities$identities$edges> ? edges, String? $__typename}) → TRes -
edges(
Iterable< Subscription$SubscribeNetworkIdentities$identities$edges> _fn(Iterable<CopyWith$Subscription$SubscribeNetworkIdentities$identities$edges< )) → TResSubscription$SubscribeNetworkIdentities$identities$edges> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited