DuplicateNetworkException class

Exception thrown in Registry constructor when _items already has an item with the RegistryItem.network.

Example:

final item1 = RegistryItem.fromJson({
     "prefix": 1,
     "network": "example",
   });

final item2 = RegistryItem.fromJson({
     "prefix": 2,
     "network": "example",
   });

final registry = Registry([item1, item2]);
Implemented types

Constructors

DuplicateNetworkException(String network)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
network String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited