DurtKeyring class

Custom Keyring that ensures all KeyPair operations return the correct SS58 format This is a RADICAL solution that replaces the default Keyring to force correct SS58 format

Constructors

DurtKeyring()

Properties

hashCode int
The hash code for this object.
no setterinherited
original Keyring
Access to original Keyring for any advanced operations that might be needed
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromMnemonic(String mnemonic, {KeyPairType? keyPairType}) Future<DurtKeyPair>
Create KeyPair from mnemonic with correct SS58 format Returns a wrapped KeyPair that automatically provides correct addresses
fromSeed(Uint8List seed, {KeyPairType? keyPairType}) DurtKeyPair
Create KeyPair from seed with correct SS58 format Returns a wrapped KeyPair that automatically provides correct addresses
fromUri(String uri, {KeyPairType? keyPairType}) Future<DurtKeyPair>
Create KeyPair from URI with correct SS58 format Returns a wrapped KeyPair that automatically provides correct addresses
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited