DurtTestConfig class

Configuration for test mode

Constructors

DurtTestConfig({MockDuniterStorageService? mockStorage, MockWalletService? mockWallets, Networks network = Networks.gdev})

Properties

hashCode int
The hash code for this object.
no setterinherited
mockStorage MockDuniterStorageService
final
mockWallets MockWalletService
final
network Networks
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited