Input$CallCondition class

Constructors

Input$CallCondition({String? id, List<int?>? address, bool? success, String? error, String? pallet, String? name, String? args, List<String?>? argsStr, String? blockId, String? extrinsicId, String? parentId})
factory
Input$CallCondition.fromJson(Map<String, dynamic> data)
factory

Properties

address List<int?>?
no setter
args String?
no setter
argsStr List<String?>?
no setter
blockId String?
no setter
copyWith CopyWith$Input$CallCondition<Input$CallCondition>
no setter
error String?
no setter
extrinsicId String?
no setter
hashCode int
The hash code for this object.
no setteroverride
id String?
no setter
name String?
no setter
pallet String?
no setter
parentId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override