Input$CallFilter class
Constructors
-
Input$CallFilter({Input$StringFilter? id, Input$IntListFilter? address, Input$BooleanFilter? success, Input$JSONFilter? error, Input$StringFilter? pallet, Input$StringFilter? name, Input$JSONFilter? args, Input$StringListFilter? argsStr, Input$StringFilter? blockId, Input$StringFilter? extrinsicId, Input$StringFilter? parentId, Input$CallToManyEventFilter? events, bool? eventsExist, Input$CallToManyCallFilter? childCalls, bool? childCallsExist, Input$CallToManyExtrinsicFilter? extrinsics, bool? extrinsicsExist, Input$BlockFilter? block, bool? blockExists, Input$ExtrinsicFilter? extrinsic, bool? extrinsicExists, Input$CallFilter? parent, bool? parentExists, List<
Input$CallFilter> ? and, List<Input$CallFilter> ? or, Input$CallFilter? not}) -
factory
-
Input$CallFilter.fromJson(Map<
String, dynamic> data) -
factory
Properties
- address → Input$IntListFilter?
-
no setter
-
and
→ List<
Input$CallFilter> ? -
no setter
- args → Input$JSONFilter?
-
no setter
- argsStr → Input$StringListFilter?
-
no setter
- block → Input$BlockFilter?
-
no setter
- blockExists → bool?
-
no setter
- blockId → Input$StringFilter?
-
no setter
- childCalls → Input$CallToManyCallFilter?
-
no setter
- childCallsExist → bool?
-
no setter
-
copyWith
→ CopyWith$Input$CallFilter<
Input$CallFilter> -
no setter
- error → Input$JSONFilter?
-
no setter
- events → Input$CallToManyEventFilter?
-
no setter
- eventsExist → bool?
-
no setter
- extrinsic → Input$ExtrinsicFilter?
-
no setter
- extrinsicExists → bool?
-
no setter
- extrinsicId → Input$StringFilter?
-
no setter
- extrinsics → Input$CallToManyExtrinsicFilter?
-
no setter
- extrinsicsExist → bool?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → Input$StringFilter?
-
no setter
- name → Input$StringFilter?
-
no setter
- not → Input$CallFilter?
-
no setter
-
or
→ List<
Input$CallFilter> ? -
no setter
- pallet → Input$StringFilter?
-
no setter
- parent → Input$CallFilter?
-
no setter
- parentExists → bool?
-
no setter
- parentId → Input$StringFilter?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → Input$BooleanFilter?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override