Input$CallToManyEventFilter class
Constructors
- Input$CallToManyEventFilter({Input$EventFilter? every, Input$EventFilter? some, Input$EventFilter? none})
-
factory
-
Input$CallToManyEventFilter.fromJson(Map<
String, dynamic> data) -
factory
Properties
-
copyWith
→ CopyWith$Input$CallToManyEventFilter<
Input$CallToManyEventFilter> -
no setter
- every → Input$EventFilter?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- none → Input$EventFilter?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- some → Input$EventFilter?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override