Input$IntFilter class

Constructors

Input$IntFilter({bool? isNull, int? equalTo, int? notEqualTo, int? distinctFrom, int? notDistinctFrom, List<int>? $in, List<int>? notIn, int? lessThan, int? lessThanOrEqualTo, int? greaterThan, int? greaterThanOrEqualTo})
factory
Input$IntFilter.fromJson(Map<String, dynamic> data)
factory

Properties

$in List<int>?
no setter
copyWith CopyWith$Input$IntFilter<Input$IntFilter>
no setter
distinctFrom int?
no setter
equalTo int?
no setter
greaterThan int?
no setter
greaterThanOrEqualTo int?
no setter
hashCode int
The hash code for this object.
no setteroverride
isNull bool?
no setter
lessThan int?
no setter
lessThanOrEqualTo int?
no setter
notDistinctFrom int?
no setter
notEqualTo int?
no setter
notIn List<int>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override