Input$PopulationHistoryCondition class

Constructors

Input$PopulationHistoryCondition({String? id, int? smithCount, int? memberCount, int? activeAccountCount, int? blockNumber})
factory
Input$PopulationHistoryCondition.fromJson(Map<String, dynamic> data)
factory

Properties

activeAccountCount int?
no setter
blockNumber int?
no setter
copyWith CopyWith$Input$PopulationHistoryCondition<Input$PopulationHistoryCondition>
no setter
hashCode int
The hash code for this object.
no setteroverride
id String?
no setter
memberCount int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smithCount int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override