Networks class

Properties

displayName String
final
genesisHash String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
remoteConfigUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ss58 int
final
symbol String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultNetwork Networks
Returns the default network for app startup.
no setter
duniterEndpoint String
getter/setter pair
listDuniterEndpoints List<String>
getter/setter pair
listSquidEndpoints List<String>
getter/setter pair
squidEndpoint String
getter/setter pair

Constants

g1 → const Networks
gdev → const Networks
gtest → const Networks
local → const Networks
values → const List<Networks>