RegistryItem class

RegistryItem for storing registry information

This class can be easily compared for equality.

Annotations
  • @JsonSerializable.new()

Constructors

RegistryItem({required int prefix, required String network})
Private constructor of RegistryItem Model
const
RegistryItem.fromJson(Map<String, dynamic> json)
Initialize Registry Item from the Json
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
network String
Unique identifier for the network that will use this prefix
final
prefix int
The address prefix (ss58 address type).
final
props List<Object?>
Used to match and calculate hashcode with equality
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
returns Json of the Registry
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited