Subscription$SubscribeNetworkActivity$transfers class
- Available extensions
Constructors
-
Subscription$SubscribeNetworkActivity$transfers({required List<
Subscription$SubscribeNetworkActivity$transfers$edges> edges, String $__typename = 'TransfersConnection'}) -
Subscription$SubscribeNetworkActivity$transfers.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
-
copyWith
→ CopyWith$Subscription$SubscribeNetworkActivity$transfers<
Subscription$SubscribeNetworkActivity$transfers> -
Available on Subscription$SubscribeNetworkActivity$transfers, provided by the UtilityExtension$Subscription$SubscribeNetworkActivity$transfers extension
no setter -
edges
→ List<
Subscription$SubscribeNetworkActivity$transfers$edges> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override