Subscription$SubscribeNetworkIdentities$identities class
- Available extensions
Constructors
-
Subscription$SubscribeNetworkIdentities$identities({required List<
Subscription$SubscribeNetworkIdentities$identities$edges> edges, String $__typename = 'IdentitiesConnection'}) -
Subscription$SubscribeNetworkIdentities$identities.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
-
copyWith
→ CopyWith$Subscription$SubscribeNetworkIdentities$identities<
Subscription$SubscribeNetworkIdentities$identities> -
Available on Subscription$SubscribeNetworkIdentities$identities, provided by the UtilityExtension$Subscription$SubscribeNetworkIdentities$identities extension
no setter -
edges
→ List<
Subscription$SubscribeNetworkIdentities$identities$edges> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override