Subscription$SubscribeNetworkIdentities class
- Available extensions
Constructors
- Subscription$SubscribeNetworkIdentities({Subscription$SubscribeNetworkIdentities$identities? identities, String $__typename = 'Subscription'})
-
Subscription$SubscribeNetworkIdentities.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
-
copyWith
→ CopyWith$Subscription$SubscribeNetworkIdentities<
Subscription$SubscribeNetworkIdentities> -
Available on Subscription$SubscribeNetworkIdentities, provided by the UtilityExtension$Subscription$SubscribeNetworkIdentities extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- identities → Subscription$SubscribeNetworkIdentities$identities?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override