Variables$Query$GetNetworkCertificationsFiltered class

Properties

after String?
no setter
before String?
no setter
copyWith CopyWith$Variables$Query$GetNetworkCertificationsFiltered<Variables$Query$GetNetworkCertificationsFiltered>
no setter
filter Input$CertFilter?
no setter
first int?
no setter
hashCode int
The hash code for this object.
no setteroverride
last int?
no setter
orderBy List<Enum$CertsOrderBy>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override