CertState class
Constructors
- CertState({required CertStatus status, Duration? duration, int? nextIssuableBlock, DateTime? nextIssuableDate})
Properties
- duration → Duration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mustWait → bool
-
Whether the issuer must wait before certifying
no setter
- nextIssuableBlock → int?
-
Block number when the next certification can be issued
final
- nextIssuableDate → DateTime?
-
Estimated date/time when the next certification can be issued
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CertStatus
-
final
Methods
-
copyWith(
{CertStatus? status, Duration? duration, int? nextIssuableBlock, DateTime? nextIssuableDate}) → CertState - Copy with updated fields
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited