CopyWith$Query$GetNetworkCertificationsFiltered$certs<TRes> class
abstract
Constructors
- CopyWith$Query$GetNetworkCertificationsFiltered$certs(Query$GetNetworkCertificationsFiltered$certs instance, TRes then(Query$GetNetworkCertificationsFiltered$certs))
-
factory
- CopyWith$Query$GetNetworkCertificationsFiltered$certs.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pageInfo
→ CopyWith$Query$GetNetworkCertificationsFiltered$certs$pageInfo<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{List< Query$GetNetworkCertificationsFiltered$certs$edges> ? edges, Query$GetNetworkCertificationsFiltered$certs$pageInfo? pageInfo, String? $__typename}) → TRes -
edges(
Iterable< Query$GetNetworkCertificationsFiltered$certs$edges> _fn(Iterable<CopyWith$Query$GetNetworkCertificationsFiltered$certs$edges< )) → TResQuery$GetNetworkCertificationsFiltered$certs$edges> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited