DurtTestMode class
Test mode singleton for Durt Allows running tests without network connections
Properties
- config → DurtTestConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → MockDuniterStorageService
-
no setter
- wallets → MockWalletService
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- i → DurtTestMode
-
no setter
- instance → DurtTestMode
-
no setter
- isTestMode → bool
-
no setter
Static Methods
-
init(
{DurtTestConfig? config}) → Future< DurtTestMode> - Initialize Durt in test mode This creates a minimal Durt instance that doesn't connect to any network
-
reset(
) → void - Reset test mode (call in tearDown)