Enum$BlocksOrderBy enum
- Inheritance
- Available extensions
Values
- NATURAL → const Enum$BlocksOrderBy
- ID_ASC → const Enum$BlocksOrderBy
- ID_DESC → const Enum$BlocksOrderBy
- HEIGHT_ASC → const Enum$BlocksOrderBy
- HEIGHT_DESC → const Enum$BlocksOrderBy
- HASH_ASC → const Enum$BlocksOrderBy
- HASH_DESC → const Enum$BlocksOrderBy
- PARENT_HASH_ASC → const Enum$BlocksOrderBy
- PARENT_HASH_DESC → const Enum$BlocksOrderBy
- STATE_ROOT_ASC → const Enum$BlocksOrderBy
- STATE_ROOT_DESC → const Enum$BlocksOrderBy
- EXTRINSICSIC_ROOT_ASC → const Enum$BlocksOrderBy
- EXTRINSICSIC_ROOT_DESC → const Enum$BlocksOrderBy
- SPEC_NAME_ASC → const Enum$BlocksOrderBy
- SPEC_NAME_DESC → const Enum$BlocksOrderBy
- SPEC_VERSION_ASC → const Enum$BlocksOrderBy
- SPEC_VERSION_DESC → const Enum$BlocksOrderBy
- IMPL_NAME_ASC → const Enum$BlocksOrderBy
- IMPL_NAME_DESC → const Enum$BlocksOrderBy
- IMPL_VERSION_ASC → const Enum$BlocksOrderBy
- IMPL_VERSION_DESC → const Enum$BlocksOrderBy
- TIMESTAMP_ASC → const Enum$BlocksOrderBy
- TIMESTAMP_DESC → const Enum$BlocksOrderBy
- VALIDATOR_ASC → const Enum$BlocksOrderBy
- VALIDATOR_DESC → const Enum$BlocksOrderBy
- EXTRINSICS_COUNT_ASC → const Enum$BlocksOrderBy
- EXTRINSICS_COUNT_DESC → const Enum$BlocksOrderBy
- CALLS_COUNT_ASC → const Enum$BlocksOrderBy
- CALLS_COUNT_DESC → const Enum$BlocksOrderBy
- EVENTS_COUNT_ASC → const Enum$BlocksOrderBy
- EVENTS_COUNT_DESC → const Enum$BlocksOrderBy
- PRIMARY_KEY_ASC → const Enum$BlocksOrderBy
- PRIMARY_KEY_DESC → const Enum$BlocksOrderBy
- $unknown → const Enum$BlocksOrderBy
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encodeTo(
Output output) → void -
Available on T, provided by the EnumExtensions extension
Encodes value of Enum to the HexOutput / ByteOutput -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Enum$BlocksOrderBy> - A constant List of the values in this enum, in order of their declaration.