Input$UdReevalCondition class
Constructors
Properties
- blockNumber → int?
-
no setter
-
copyWith
→ CopyWith$Input$UdReevalCondition<
Input$UdReevalCondition> -
no setter
- eventId → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String?
-
no setter
- membersCount → int?
-
no setter
- monetaryMass → String?
-
no setter
- newUdAmount → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String?
-
no setter
- udIndex → int?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override